<?php

/**
 * Return "user info" content type.
 */
function userinfo_content_type() {
  return array(
    'description' => array(
      'title' => t('User Info'),
      'icon' => 'icon_user.png',
      'path' => panels_get_path('content_types/user'),
      'description' => t('User information gathered from helper modules.'),
      'required context' => new panels_required_context(t('User'), 'user'),
      'category' => array(t('User context'), -9),
    ),
  );
}

/**
 * Output function for the 'user info' content type.
 */
function userinfo_content($conf, $panel_args, $context) {
  $accountid = isset($context->data) ? drupal_clone($context->data) : NULL;
  $block->module = 'userinfo';
  $block->title = "User Info";
  
  if ($accountid) {
    $vars = userinfo_uservars($vars, $accountid->uid); 
    $block->content = theme('userinfo', $accountid, $vars); 
  } else {
    $block->content = "No content available";
  }

  return $block;
}

/**
 * Creates variables related to the given user, mostly from functions provided by other modules.
 * The "$vars" parameter allows this to be called from _phptemplate_variables as well
 */
function userinfo_uservars($vars, $accountid) {
  $themedir = advanced_profile_get_theme_directory();
  
  // Get a reference to the currently logged in user. 
  // The passed in $accountid will refer to the user who's info is in the pane.
  global $user;
  
  // Load the account to use in gathering account info
  $account = user_load(array('uid'=>$accountid));

  // Avatar
  $vars['picture'] = theme('user_picture',$account);

  // Join date / since
  $vars['joined-raw'] = format_date($account->created, 'custom', 'Y-m-d');
  $vars['joined'] = '<div class="account-joined">' . t('Joined: ') . $vars['joined-raw'] . '</div>';

  $vars['member_since-raw'] = format_interval(time() - $account->created);
  $vars['member_since'] = '<div class="account-member-since">' . t('Member since: ') . $vars['member_since-raw'] . '</div>';
  
  // Online status
  if (round((time()-$account->access)/60) < 15) {
    $vars['online_status'] = theme('user_info_online',$accountid, TRUE,TRUE);
  } else {
    $vars['online_status'] = theme('user_info_online',$accountid, TRUE,FALSE);
  }

  // Points
  if (module_exists('userpoints')) {
    $vars['points-raw'] = userpoints_get_current_points($accountid);
    $vars['points'] = '<div class="account-points">' . t('Posts: ') . $vars['points-raw'] . '</div>';
  }

  // Posts
  if (module_exists('user_postcounts')) {
    $vars['posts-raw'] = user_postcounts_get_postcount($accountid);
    $vars['posts'] = '<div class="account-posts">' . t('Posts: ') . $vars['posts-raw'] . '</div>';
  }
 
  // Title
  if (module_exists('user_titles')) {
    $vars['user_title-raw'] = user_titles_get_user_title($accountid);
    $vars['user_title'] = '<div class="account-title">' . $vars['user_title-raw'] . '</div>';
  }

  // Badges
  if (module_exists('user_badges')) {
    $vars['user_badges-raw'] = user_badges_for_uid($accountid);
    $vars['user_badges'] = '<div class="account-badges">' . $vars['user_badges-raw'] . '</div>';
  }

  // Email user
  if (($account->contact) && ($account->uid != $user->uid) && ($user->uid != 0)) {
      $vars['contact'] = theme('user_info_contact',$accountid, TRUE);
  } 
           
  // Send private message
  if (module_exists('privatemsg') && user_access('access private messages') && 
  (isset($account->privatemsg_allow) ? $account->privatemsg_allow : 1)) { 
    $vars['privatemsg'] = theme('user_info_privatemsg',$accountid, TRUE);
  } 
            
  // Add / remove from buddylist
  if (module_exists('buddylist')) {
    if (user_access('maintain buddy list') && @in_array($accountid, array_keys(buddylist_get_buddies($user->uid)))) {
      // Remove buddy
      $vars['buddylist'] = theme('user_info_buddylist',$accountid, TRUE,FALSE);
    } else {
      // Add buddy
      if ($accountid != $user->uid && user_access('maintain buddy list')) {
        $vars['buddylist'] = theme('user_info_buddylist',$accountid, TRUE,TRUE);
      }
    }
  }
 
  return $vars;
}


/**
 * Theme function for online status
 */
function theme_user_info_online($accountid, $verbose, $online) {
  $themedir = advanced_profile_get_theme_directory();

  if ($online) {
    $icon =  theme_image(path_to_theme() . '/' . $themedir . '/images/status_online.png', 'User is online', 'User is online',NULL, TRUE);
    if ($verbose) { $text = ' ' . t('Online now'); }
  } else {
    $icon =  theme_image(path_to_theme() . '/' . $themedir . '/images/status_offline.png', 'User is offline', 'User is offline',NULL, TRUE);
    if ($verbose) { $text = ' ' . t('Offline'); }
  }
  
  return '<div class="online">' . $icon . $text . '</div>'; 
}


/**
 * Theme function for contact link/icon
 */
function theme_user_info_contact($accountid, $verbose) {
  if ($verbose) {
    $text = ' ' . t('Email');
  }
  
  $themedir = advanced_profile_get_theme_directory();
  $icon =  theme_image(path_to_theme() . '/' . $themedir . "/images/email.png", 'Email', 'Email', NULL, TRUE);
  return '<div class="contact">' . l($icon . $text, 'user/'. $accountid . '/contact',NULL,NULL,NULL,NULL,TRUE) . '</div>'; 
}

/**
 * Theme function for private message link/icon
 */
function theme_user_info_privatemsg($accountid, $verbose) {
  if ($verbose) {
    $text = ' ' . t('Send PM');
  }
  
  $themedir = advanced_profile_get_theme_directory();
  $icon =  theme_image(path_to_theme() . '/' . $themedir . "/images/user_comment.png", 'Private Message', 'Private Message', NULL, TRUE);
  return '<div class="pm">' . l($icon . $text, 'privatemsg/new/'. $accountid,NULL,NULL,NULL,NULL,TRUE) . '</div>'; 
}

/**
 * Theme function for buddylist icon
 */
function theme_user_info_buddylist($accountid, $verbose, $add) {
  $themedir = advanced_profile_get_theme_directory();

  if ($add) {
    $icon =  theme_image(path_to_theme() . '/' . $themedir . "/images/group_add.png", 'Add to buddy list', 'Add to buddy list', NULL, TRUE);
    if ($verbose) { $text = ' ' . t('Add buddy'); }
  } else {
    $icon =  theme_image(path_to_theme() . '/' . $themedir . "/images/group_delete.png", 'Remove Buddy', 'Remove Buddy', NULL, TRUE);
    if ($verbose) { $text = ' ' . t('Remove buddy'); }
  }
  
  return '<div class="online">' . l($icon . $text, 'buddy/add/'. $accountid,NULL,NULL,NULL,NULL,TRUE) . '</div>'; 
}

/**
 * Theme function for the user pane. Takes in the variables created in userinfo_uservars
 */
function theme_userinfo($accountid, $vars) {
  $themedir = advanced_profile_get_theme_directory();
  
  if (file_exists($themedir . '/panel-user-info.tpl.php')) {
    return _phptemplate_callback($themedir . '/panel-user-info',array_merge(array('accountid'=>$accountid), $vars));
  } else {
    //No .tpl file so output some basic formatting.
    $output = '<div class="user-stuff">';
    $output .= $vars['picture']; 
    $output .= $vars['user_title']; 
    $output .= $vars['posts']; 
    $output .= $vars['joined']; 
    $output .= $vars['points'];
    $output .= $vars['user_badges']; 
    $output .= $vars['online_status']; 
    $output .= $vars['contact']; 
    $output .= $vars['privatemsg']; 
    $output .= $vars['buddylist']; 
    $output .= '</div>';

    return $output;
  }
}
